==> google_cloud_service_usage-1.3.0-py2.py3-none-any.whl: google/cloud/service_usage/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.service_usage_v1.services.service_usage.client import (
    ServiceUsageClient,
)
from google.cloud.service_usage_v1.services.service_usage.async_client import (
    ServiceUsageAsyncClient,
)

from google.cloud.service_usage_v1.types.resources import OperationMetadata
from google.cloud.service_usage_v1.types.resources import Service
from google.cloud.service_usage_v1.types.resources import ServiceConfig
from google.cloud.service_usage_v1.types.resources import State
from google.cloud.service_usage_v1.types.serviceusage import BatchEnableServicesRequest
from google.cloud.service_usage_v1.types.serviceusage import BatchEnableServicesResponse
from google.cloud.service_usage_v1.types.serviceusage import BatchGetServicesRequest
from google.cloud.service_usage_v1.types.serviceusage import BatchGetServicesResponse
from google.cloud.service_usage_v1.types.serviceusage import DisableServiceRequest
from google.cloud.service_usage_v1.types.serviceusage import DisableServiceResponse
from google.cloud.service_usage_v1.types.serviceusage import EnableServiceRequest
from google.cloud.service_usage_v1.types.serviceusage import EnableServiceResponse
from google.cloud.service_usage_v1.types.serviceusage import GetServiceRequest
from google.cloud.service_usage_v1.types.serviceusage import ListServicesRequest
from google.cloud.service_usage_v1.types.serviceusage import ListServicesResponse

__all__ = (
    "ServiceUsageClient",
    "ServiceUsageAsyncClient",
    "OperationMetadata",
    "Service",
    "ServiceConfig",
    "State",
    "BatchEnableServicesRequest",
    "BatchEnableServicesResponse",
    "BatchGetServicesRequest",
    "BatchGetServicesResponse",
    "DisableServiceRequest",
    "DisableServiceResponse",
    "EnableServiceRequest",
    "EnableServiceResponse",
    "GetServiceRequest",
    "ListServicesRequest",
    "ListServicesResponse",
)

==> google_cloud_service_usage-1.3.2-py2.py3-none-any.whl: google/cloud/service_usage/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.service_usage_v1.services.service_usage.async_client import (
    ServiceUsageAsyncClient,
)
from google.cloud.service_usage_v1.services.service_usage.client import (
    ServiceUsageClient,
)
from google.cloud.service_usage_v1.types.resources import (
    OperationMetadata,
    Service,
    ServiceConfig,
    State,
)
from google.cloud.service_usage_v1.types.serviceusage import (
    BatchEnableServicesRequest,
    BatchEnableServicesResponse,
    BatchGetServicesRequest,
    BatchGetServicesResponse,
    DisableServiceRequest,
    DisableServiceResponse,
    EnableServiceRequest,
    EnableServiceResponse,
    GetServiceRequest,
    ListServicesRequest,
    ListServicesResponse,
)

__all__ = (
    "ServiceUsageClient",
    "ServiceUsageAsyncClient",
    "OperationMetadata",
    "Service",
    "ServiceConfig",
    "State",
    "BatchEnableServicesRequest",
    "BatchEnableServicesResponse",
    "BatchGetServicesRequest",
    "BatchGetServicesResponse",
    "DisableServiceRequest",
    "DisableServiceResponse",
    "EnableServiceRequest",
    "EnableServiceResponse",
    "GetServiceRequest",
    "ListServicesRequest",
    "ListServicesResponse",
)
